Summary:        A SAT solver
Name:           picosat
Version:        965
Release:        1%{?dist}
License:        MIT
URL:            http://fmv.jku.at/picosat/
Source0:        %{url}%{name}-%{version}.tar.gz

Patch3000:      %{name}-trace.patch

BuildRequires:  gcc make R-core-devel
Requires:       bzip2 gzip %{name}-libs = %{version}-%{release}

%description
PicoSAT solves the SAT problem, which is the classical NP complete problem of
searching for a satisfying assignment of a propositional formula in conjunctive
normal form (CNF).  PicoSAT can generate proofs and cores in memory by
compressing the proof trace.  It supports the proof format of TraceCheck.

%package R
Summary:        A SAT solver library for R

%description R
The PicoSAT library, which contains routines that solve the SAT problem.  The
library has a simple API which is similar to that of previous solvers by the
same authors.  This version of the library is built for use with R projects.

%package libs
Summary:        A SAT solver library

%description libs
The PicoSAT library, which contains routines that solve the SAT problem.  The
library has a simple API which is similar to that of previous solvers by the
same authors.

%package devel
Summary:        Development files for PicoSAT
Requires:       %{name}-R = %{version}-%{release}
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Headers and other development files for PicoSAT.

%prep
%autosetup -n %{name}-%{version} -p1

%build
sed -e 's/@CC@/gcc/' \
    -e 's|@CFLAGS@|%{build_cflags} -D_GNU_SOURCE=1 -DNDEBUG -DRCODE -I%{_includedir}/R|' \
    -e 's|-Xlinker libpicosat.so|-Xlinker libpicosat.so.0 %{build_ldflags} -L%{_libdir}/R/lib -lR|' \
    -e 's/libpicosat/libpicosat-R/g' \
    -e 's/-lpicosat/-lpicosat-R/g' \
    -e 's/@TARGETS@/libpicosat-R.so/' \
  makefile.in > makefile
%make_build

sed -e 's/@CC@/gcc/' \
    -e 's|@CFLAGS@|%{build_cflags} -D_GNU_SOURCE=1 -DNDEBUG -DTRACE|' \
    -e 's|-Xlinker libpicosat.so|-Xlinker libpicosat.so.0 %{build_ldflags}|' \
    -e 's/libpicosat/libpicosat-trace/g' \
    -e 's/-lpicosat/-lpicosat-trace/g' \
    -e 's/@TARGETS@/libpicosat-trace.so picosat picomus/' \
  makefile.in > makefile
%make_build
mv picosat picosat.trace

rm -f *.o *.s config.h
sed -e 's/@CC@/gcc/' \
    -e 's|@CFLAGS@|%{build_cflags} -D_GNU_SOURCE=1 -DNDEBUG|' \
    -e 's|-Xlinker libpicosat.so|-Xlinker libpicosat.so.0 %{build_ldflags}|' \
    -e 's/@TARGETS@/libpicosat.so picosat picomcs picogcnf/' \
  makefile.in > makefile
%make_build

%install
install -Dp picosat.h %{buildroot}%{_includedir}/picosat.h

mkdir -p %{buildroot}%{_libdir}
install -m 0755 -p libpicosat-R.so \
  %{buildroot}%{_libdir}/libpicosat-R.so.0.0.%{version}
ln -s libpicosat-R.so.0.0.%{version} %{buildroot}%{_libdir}/libpicosat-R.so.0
ln -s libpicosat-R.so.0 %{buildroot}%{_libdir}/libpicosat-R.so

install -m 0755 -p libpicosat-trace.so \
  %{buildroot}%{_libdir}/libpicosat-trace.so.0.0.%{version}
ln -s libpicosat-trace.so.0.0.%{version} %{buildroot}%{_libdir}/libpicosat-trace.so.0
ln -s libpicosat-trace.so.0 %{buildroot}%{_libdir}/libpicosat-trace.so

install -m 0755 -p libpicosat.so \
  %{buildroot}%{_libdir}/libpicosat.so.0.0.%{version}
ln -s libpicosat.so.0.0.%{version} %{buildroot}%{_libdir}/libpicosat.so.0
ln -s libpicosat.so.0 %{buildroot}%{_libdir}/libpicosat.so

mkdir -p %{buildroot}%{_bindir}
install -m 0755 -p picosat picosat.trace picomus picomcs picogcnf \
  %{buildroot}%{_bindir}

%files
%{_bindir}/pico*

%files R
%license LICENSE
%doc NEWS
%{_libdir}/libpicosat-R.so.0*

%files libs
%license LICENSE
%doc NEWS
%{_libdir}/libpicosat-trace.so.0*
%{_libdir}/libpicosat.so.0*

%files devel
%{_includedir}/picosat.h
%{_libdir}/libpicosat-R.so
%{_libdir}/libpicosat-trace.so
%{_libdir}/libpicosat.so

%changelog
* Mon Dec 11 2023 Shuo Wang <abushwang@tencent.com> - 965-1
- initial build
